# BEGIN SourceDeps(oneline):
BuildRequires(pre): rpm-macros-fedora-compat
BuildRequires: gcc-c++
# END SourceDeps(oneline)
Name:           mlpack
Version:        1.0.4
Release:        alt1_3
Summary:        Scalable, fast C++ machine learning library

Group:          System/Libraries
License:        LGPLv3+
URL:            http://www.mlpack.org
Source0:        http://www.mlpack.org/files/%{name}-%{version}.tar.gz

# CMake by default doesn't provide support for specifying libdir on install
# (argh!) and this has to be done by hand in the CMake configuration.  This'll
# be fixed by mlpack 1.0.2.
Patch0:         cmake_libdir.patch


# Use cmake28 package on RHEL.
%if 0%{?rhel}
BuildRequires:  cmake28 >= 2.8.5
%else
BuildRequires: ctest cmake
%endif

# 2.4.0 precipitated an internal Armadillo switch from 'u32' to 'uword' and the
# Armadillo extensions in mlpack depend on the use of 'uword' which is
# undefined <= 2.4.0.
BuildRequires:  libarmadillo-devel >= 2.4.2
BuildRequires:  libxml2-devel
BuildRequires: boost-devel boost-filesystem-devel boost-wave-devel boost-graph-parallel-devel boost-math-devel boost-mpi-devel boost-program_options-devel boost-signals-devel boost-intrusive-devel boost-asio-devel boost-program-options boost-math
BuildRequires:  liblapack-devel
# For generating man pages (CMake configuration takes care of this assuming
# txt2man is installed).  It is possible that we could just add all the man
# pages, generated offline, as a patch to this SRPM, but txt2man seems to exist
# in repos.
BuildRequires:  txt2man
# For generation of Doxygen HTML documentation.
BuildRequires:  doxygen

# something doesn't like size_t being unsigned long on s390
ExcludeArch:    s390
Source44: import.info

%description
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use. Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users. mlpack outperforms competing machine learning libraries by large
margins.

# Executables.
%package bin
Summary:        Command-line executables for mlpack (machine learning library)
Group:          Engineering
Requires:       %{name} = %{version}-%{release}

%description bin
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use. Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users. mlpack outperforms competing machine learning libraries by large
margins.  This package provides the command-line executables which run mlpack
methods and related documentation.

# Development headers.
%package devel
Summary:        Development headers for mlpack (C++ machine learning library)
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}
Requires: boost-program-options boost-math

%description devel
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use. Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users. mlpack outperforms competing machine learning libraries by large
margins.  This package provides the headers to compile applications against
mlpack.



%package doc
Summary:        Doxygen documentation for mlpack (C++ machine learning library)
Group:          Documentation

%description doc
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use.  Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users.  mlpack outperforms competing machine learning libraries by large
margins.  This package provides the Doxygen-generated documentation for mlpack.


%prep
%setup -q
%patch0 -p1


%build
%if 0%{?rhel}
%{cmake28} -D LIBDIR=%{_libdir} -D DEBUG=OFF -D PROFILE=OFF .
%else
%{fedora_cmake} -D LIBDIR=%{_libdir} -D DEBUG=OFF -D PROFILE=OFF .
%endif

make %{?_smp_mflags}
# Build documentation ('doc' is not in the list of default targets).
make doc


%install
make install DESTDIR=$RPM_BUILD_ROOT

# Put the license file in place.
mkdir -p $RPM_BUILD_ROOT/%{_docdir}/%{name}-%{version}/

# Rename executables to mlpack_* to avoid possible naming collisions.  Upstream
# bug report http://trac.research.cc.gatech.edu/fastlab/ticket/236.
for i in `ls $RPM_BUILD_ROOT/%{_bindir}`
do
  %{__mv} $RPM_BUILD_ROOT/%{_bindir}/$i $RPM_BUILD_ROOT/%{_bindir}/mlpack_$i;
done
for i in `ls $RPM_BUILD_ROOT/%{_mandir}/man1`
do
  %{__mv} $RPM_BUILD_ROOT/%{_mandir}/man1/$i $RPM_BUILD_ROOT/%{_mandir}/man1/mlpack_$i;
done

%files
%{_libdir}/libmlpack.so.1
%{_libdir}/libmlpack.so.1.0
%doc LICENSE.txt

%files bin
%{_bindir}/mlpack_allknn
%{_bindir}/mlpack_allkfn
%{_bindir}/mlpack_det
%{_bindir}/mlpack_emst
%{_bindir}/mlpack_gmm
%{_bindir}/mlpack_hmm_generate
%{_bindir}/mlpack_hmm_loglik
%{_bindir}/mlpack_hmm_train
%{_bindir}/mlpack_hmm_viterbi
%{_bindir}/mlpack_kernel_pca
%{_bindir}/mlpack_kmeans
%{_bindir}/mlpack_lars
%{_bindir}/mlpack_linear_regression
%{_bindir}/mlpack_local_coordinate_coding
%{_bindir}/mlpack_mvu
%{_bindir}/mlpack_nbc
%{_bindir}/mlpack_nca
%{_bindir}/mlpack_nmf
%{_bindir}/mlpack_pca
%{_bindir}/mlpack_radical
%{_bindir}/mlpack_range_search
%{_bindir}/mlpack_sparse_coding
%{_mandir}/man1/mlpack_allknn.1*
%{_mandir}/man1/mlpack_allkfn.1*
%{_mandir}/man1/mlpack_det.1*
%{_mandir}/man1/mlpack_emst.1*
%{_mandir}/man1/mlpack_gmm.1*
%{_mandir}/man1/mlpack_hmm_generate.1*
%{_mandir}/man1/mlpack_hmm_loglik.1*
%{_mandir}/man1/mlpack_hmm_train.1*
%{_mandir}/man1/mlpack_hmm_viterbi.1*
%{_mandir}/man1/mlpack_kernel_pca.1*
%{_mandir}/man1/mlpack_kmeans.1*
%{_mandir}/man1/mlpack_lars.1*
%{_mandir}/man1/mlpack_linear_regression.1*
%{_mandir}/man1/mlpack_local_coordinate_coding.1*
%{_mandir}/man1/mlpack_mvu.1*
%{_mandir}/man1/mlpack_nbc.1*
%{_mandir}/man1/mlpack_nca.1*
%{_mandir}/man1/mlpack_nmf.1*
%{_mandir}/man1/mlpack_pca.1*
%{_mandir}/man1/mlpack_radical.1*
%{_mandir}/man1/mlpack_range_search.1*
%{_mandir}/man1/mlpack_sparse_coding.1*

%files devel
%{_libdir}/libmlpack.so
%{_includedir}/mlpack/

%files doc
%{_docdir}/mlpack/

%changelog
* Fri Apr 26 2013 Igor Vlasenko <viy@altlinux.ru> 1.0.4-alt1_3
- initial fc import

